==> chimera-ble-0.1.4-sources.jar: com/chimeraiot/android/ble/BleUtils.java <==
/*
 * Copyright (c) 2015 Chimera IoT
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.chimeraiot.android.ble;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothGatt;
import android.bluetooth.BluetoothGattCharacteristic;
import android.bluetooth.BluetoothManager;
import android.content.Context;
import android.content.pm.PackageManager;

/** BLE utilities. */
public final class BleUtils {

    /** BLE enables status. */
    public static final int STATUS_BLE_ENABLED = 0;
    /** Bluetooth device is not available status. */
    public static final int STATUS_BLUETOOTH_NOT_AVAILABLE = 1;
    /** BLE is not supported status. */
    public static final int STATUS_BLE_NOT_AVAILABLE = 2;
    /** Bluetooth disabled status. */
    public static final int STATUS_BLUETOOTH_DISABLED = 3;

    private BleUtils() {
        // prevent instantiation.
    }

    /**
     * Provides bluetooth adapter from system services.
     * @param context - used to get bluetooth system service.
     * @return bluetooth adapter.
     */
    public static BluetoothAdapter getBluetoothAdapter(Context context) {
        // Initializes a Bluetooth adapter.  For API level 18 and above, get a reference to
        // BluetoothAdapter through BluetoothManager.
        final BluetoothManager bluetoothManager =
                (BluetoothManager) context.getSystemService(Context.BLUETOOTH_SERVICE);
        if (bluetoothManager == null) {
            return null;
        }
        return bluetoothManager.getAdapter();
    }

    /**
     * Return current BLE status.
     * @param context - used to get BLE device.
     * @return one of next statuses:
     * {@link #STATUS_BLE_ENABLED},
     * {@link #STATUS_BLE_NOT_AVAILABLE},
     * {@link #STATUS_BLUETOOTH_DISABLED},
     * {@link #STATUS_BLUETOOTH_NOT_AVAILABLE}
     */
    public static int getBleStatus(Context context) {
        // Use this check to determine whether BLE is supported on the device.  Then you can
        // selectively disable BLE-related features.
        if (!context.getPackageManager().hasSystemFeature(PackageManager.FEATURE_BLUETOOTH_LE)) {
            return STATUS_BLE_NOT_AVAILABLE;
        }

        final BluetoothAdapter adapter = getBluetoothAdapter(context);
        // Checks if Bluetooth is supported on the device.
        if (adapter == null) {
            return STATUS_BLUETOOTH_NOT_AVAILABLE;
        }

        if (!adapter.isEnabled()) {
            return STATUS_BLUETOOTH_DISABLED;
        }

        return STATUS_BLE_ENABLED;
    }

    /** Generates BLE executor. */
    public static BleGattExecutor createExecutor(final BleExecutorListener listener) {
        return new BleGattExecutor() {
            @Override
            public void onConnectionStateChange(BluetoothGatt gatt, int status, int newState) {
                super.onConnectionStateChange(gatt, status, newState);
                listener.onConnectionStateChange(gatt, status, newState);
            }

            @Override
            public void onServicesDiscovered(BluetoothGatt gatt, int status) {
                super.onServicesDiscovered(gatt, status);
                listener.onServicesDiscovered(gatt, status);
            }

            @Override
            public void onCharacteristicRead(BluetoothGatt gatt,
                                             BluetoothGattCharacteristic characteristic,
                                             int status) {
                super.onCharacteristicRead(gatt, characteristic, status);
                listener.onCharacteristicRead(gatt, characteristic, status);
            }

            @Override
            public void onCharacteristicChanged(BluetoothGatt gatt,
                                                BluetoothGattCharacteristic characteristic) {
                super.onCharacteristicChanged(gatt, characteristic);
                listener.onCharacteristicChanged(gatt, characteristic);
            }
        };
    }
}

==> chimera-ble-0.1.6-sources.jar: com/chimeraiot/android/ble/BleUtils.java <==
/*
 * Copyright (c) 2015 Chimera IoT
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.chimeraiot.android.ble;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothGatt;
import android.bluetooth.BluetoothGattCharacteristic;
import android.bluetooth.BluetoothManager;
import android.content.Context;
import android.content.pm.PackageManager;
import android.support.annotation.IntDef;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/** BLE utilities. */
public final class BleUtils {

    /** BLE enables status. */
    public static final int STATUS_BLE_ENABLED = 0;
    /** Bluetooth device is not available status. */
    public static final int STATUS_BLUETOOTH_NOT_AVAILABLE = 1;
    /** BLE is not supported status. */
    public static final int STATUS_BLE_NOT_AVAILABLE = 2;
    /** Bluetooth disabled status. */
    public static final int STATUS_BLUETOOTH_DISABLED = 3;

    /** BLE status. */
    @IntDef({
            STATUS_BLE_ENABLED,
            STATUS_BLUETOOTH_NOT_AVAILABLE,
            STATUS_BLE_NOT_AVAILABLE,
            STATUS_BLUETOOTH_DISABLED
    })
    @Retention(RetentionPolicy.SOURCE)
    public @interface BleStatus {
    }

    private BleUtils() {
        // prevent instantiation.
    }

    /**
     * Provides bluetooth adapter from system services.
     * @param context - used to get bluetooth system service.
     * @return bluetooth adapter.
     */
    @Nullable
    public static BluetoothAdapter getBluetoothAdapter(Context context) {
        final BluetoothManager bluetoothManager =
                (BluetoothManager) context.getSystemService(Context.BLUETOOTH_SERVICE);
        if (bluetoothManager == null) {
            return null;
        }
        return bluetoothManager.getAdapter();
    }

    /**
     * Return current BLE status.
     * @param context - used to get BLE device.
     * @return one of next statuses:
     * {@link #STATUS_BLE_ENABLED},
     * {@link #STATUS_BLE_NOT_AVAILABLE},
     * {@link #STATUS_BLUETOOTH_DISABLED},
     * {@link #STATUS_BLUETOOTH_NOT_AVAILABLE}
     */
    @BleStatus
    public static int getBleStatus(Context context) {
        // Use this check to determine whether BLE is supported on the device.  Then you can
        // selectively disable BLE-related features.
        if (!context.getPackageManager().hasSystemFeature(PackageManager.FEATURE_BLUETOOTH_LE)) {
            return STATUS_BLE_NOT_AVAILABLE;
        }

        final BluetoothAdapter adapter = getBluetoothAdapter(context);
        // Checks if Bluetooth is supported on the device.
        if (adapter == null) {
            return STATUS_BLUETOOTH_NOT_AVAILABLE;
        }

        if (!adapter.isEnabled()) {
            return STATUS_BLUETOOTH_DISABLED;
        }

        return STATUS_BLE_ENABLED;
    }

    /** Generates BLE executor. */
    public static BleGattExecutor createExecutor(@NonNull final BleExecutorListener listener) {
        return new BleGattExecutor() {
            @Override
            public void onConnectionStateChange(BluetoothGatt gatt, int status, int newState) {
                super.onConnectionStateChange(gatt, status, newState);
                listener.onConnectionStateChange(gatt, status, newState);
            }

            @Override
            public void onServicesDiscovered(BluetoothGatt gatt, int status) {
                super.onServicesDiscovered(gatt, status);
                listener.onServicesDiscovered(gatt, status);
            }

            @Override
            public void onCharacteristicRead(BluetoothGatt gatt,
                                             BluetoothGattCharacteristic characteristic,
                                             int status) {
                super.onCharacteristicRead(gatt, characteristic, status);
                listener.onCharacteristicRead(gatt, characteristic, status);
            }

            @Override
            public void onCharacteristicChanged(BluetoothGatt gatt,
                                                BluetoothGattCharacteristic characteristic) {
                super.onCharacteristicChanged(gatt, characteristic);
                listener.onCharacteristicChanged(gatt, characteristic);
            }
        };
    }
}
